==> qtjambi-webenginecore-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiWebEngineCore/QWebEngineQuotaRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWebEngineCore/qwebenginequotarequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineQuotaRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineQuotaRequest")
    QWebEngineQuotaRequest *_ptr = reinterpret_cast<QWebEngineQuotaRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineQuotaRequest()
void __qt_construct_QWebEngineQuotaRequest_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineQuotaRequest()")
    Q_UNUSED(__java_arguments)
    QWebEngineQuotaRequest *__qt_this = new(__qtjambi_ptr) QWebEngineQuotaRequest();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineQuotaRequest
void __qt_destruct_QWebEngineQuotaRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineQuotaRequest")
    reinterpret_cast<QWebEngineQuotaRequest*>(ptr)->~QWebEngineQuotaRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineQuotaRequest::QWebEngineQuotaRequest()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineQuotaRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineQuotaRequest::QWebEngineQuotaRequest()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineQuotaRequest_0, sizeof(QWebEngineQuotaRequest), typeid(QWebEngineQuotaRequest), false, &deleter_QWebEngineQuotaRequest, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineQuotaRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineQuotaRequest::operator==(QWebEngineQuotaRequest)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_operator_1equal_1native_1cref_1QWebEngineQuotaRequest_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID that0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::operator==(QWebEngineQuotaRequest)const", __qt_this)
        const QWebEngineQuotaRequest& __qt_that0 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineQuotaRequest>(that0);
        __java_return_value = (*__qt_this) == __qt_that0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineQuotaRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineQuotaRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineQuotaRequest::requestedSize()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_requestedSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::requestedSize()const", __qt_this)
        qint64 __qt_return_value = __qt_this->requestedSize();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineQuotaRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineQuotaRequest>("QWebEngineQuotaRequest", "io/qt/webengine/core/QWebEngineQuotaRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineQuotaRequest, {
        ConstructorInfo(&__qt_construct_QWebEngineQuotaRequest_0, nullptr)
    });
// END: function table

    registerMetaObject(typeId, QWebEngineQuotaRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineQuotaRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineQuotaRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineQuotaRequest);
    registerMetaType<QWebEngineQuotaRequest>("QWebEngineQuotaRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-webenginecore-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWebEngineCore/QWebEngineQuotaRequest_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWebEngineCore/qwebenginequotarequest.h>
#include <QtCore/QVariant>
#include <QtCore/qurl.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambiWebEngineCore/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QWebEngineQuotaRequest(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWebEngineQuotaRequest")
    QWebEngineQuotaRequest *_ptr = reinterpret_cast<QWebEngineQuotaRequest *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QWebEngineQuotaRequest()
void __qt_construct_QWebEngineQuotaRequest_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWebEngineQuotaRequest()")
    Q_UNUSED(__java_arguments)
    QWebEngineQuotaRequest *__qt_this = new(__qtjambi_ptr) QWebEngineQuotaRequest();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QWebEngineQuotaRequest
void __qt_destruct_QWebEngineQuotaRequest(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWebEngineQuotaRequest")
    reinterpret_cast<QWebEngineQuotaRequest*>(ptr)->~QWebEngineQuotaRequest();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWebEngineQuotaRequest::QWebEngineQuotaRequest()
extern "C" QT_DEPRECATED Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_initialize_1native__Lio_qt_webengine_core_QWebEngineQuotaRequest_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWebEngineQuotaRequest::QWebEngineQuotaRequest()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWebEngineQuotaRequest_0, sizeof(QWebEngineQuotaRequest), typeid(QWebEngineQuotaRequest), false, &deleter_QWebEngineQuotaRequest, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineQuotaRequest::accept()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_accept_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::accept()", __qt_this)
        __qt_this->accept();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineQuotaRequest::operator==(QWebEngineQuotaRequest)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_equals_1native_1cref_1QWebEngineQuotaRequest_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::operator==(QWebEngineQuotaRequest)const", __qt_this)
        const QWebEngineQuotaRequest& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QWebEngineQuotaRequest>(arg__1);
        __java_return_value = (*__qt_this) == __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineQuotaRequest::origin()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_origin_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::origin()const", __qt_this)
        QUrl __qt_return_value = __qt_this->origin();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWebEngineQuotaRequest::reject()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_reject_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::reject()", __qt_this)
        __qt_this->reject();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWebEngineQuotaRequest::requestedSize()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_requestedSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWebEngineQuotaRequest::requestedSize()const", __qt_this)
        qint64 __qt_return_value = __qt_this->requestedSize();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_webengine_core_QWebEngineQuotaRequest_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QWebEngineQuotaRequest *__qt_this = QtJambiAPI::objectFromNativeId<QWebEngineQuotaRequest>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QWebEngineQuotaRequest(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QWebEngineQuotaRequest>("QWebEngineQuotaRequest", "io/qt/webengine/core/QWebEngineQuotaRequest");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QWebEngineQuotaRequest, {
        ConstructorInfo(&__qt_construct_QWebEngineQuotaRequest_0, nullptr)
    });
// END: function table

    registerMetaObject(typeId, QWebEngineQuotaRequest::staticMetaObject, false,
            {},
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==QWebEngineQuotaRequest::staticMetaObject.indexOfMethod("accept()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                if(methodIndex==QWebEngineQuotaRequest::staticMetaObject.indexOfMethod("reject()")){
                    infos << ParameterInfo(QMetaType::Void);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWebEngineQuotaRequest);
    registerMetaType<QWebEngineQuotaRequest>("QWebEngineQuotaRequest");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
